@@ -234,6 +234,10 @@ class MemoryCache(object):
 
         reschedule = True
         try:
+            # Current meters
+            Meters.aii(self.meters_prefix + "mcs.cur_bytes", self._current_data_bytes.get())
+            Meters.aii(self.meters_prefix + "mcs.cur_size_hash", len(self._hash_key))
+
             # Evict
             ms = SolBase.mscurrent()
             evicted_count = self._evict_all_expired_keys()
